@@ -16,14 +16,24 @@ Testing:  APPORT_STAGING="yes"
 
 from __future__ import absolute_import, print_function, unicode_literals
 
-import os.path
-import glob
 import re
+import sys
+import glob
+import os.path
 import subprocess
 from apport.hookutils import *
 
+has_xorglog = False
+try:
+    from xdiagnose.xorglog import XorgLog
+    has_xorglog = True
+except ImportError:
+    pass
+
+has_launchpad = False
 try:
     from launchpadlib.launchpad import Launchpad
+    has_launchpad = True
 except ImportError:
     pass
 
@@ -59,6 +69,8 @@ def retrieve_ubuntu_release_statuses():
     or None in case of a failure reading launchpad.
     '''
     releases = { }
+    if not has_launchpad:
+        return None
     try:
         lp = Launchpad.login_anonymously('apport', 'production')
         d = lp.distributions['ubuntu']
@@ -224,49 +236,6 @@ def check_is_supported(report, ui=None):
         report['UnreportableReason'] = 'Unsupported Ubuntu Release'
         return False
 
-    elif ((status == "Supported" or status == "Current Stable Release") and
-          report.get('ProblemType', '') != 'Crash'):
-        # TODO: Perhaps avoid this check if the time since the release < 1 month?
-        # lsb_release -rs gives 12.04
-        # int(release.version.split('.')[1])+2
-        response = ui.choice(
-            "'%s' is no longer under development, but technical support is still \n"
-            "available and will give you quicker results than filing a bug here.  \n"
-            "Also, if you do have a bug, we will give it higher priority if you've gone \n"
-            "through technical support channels first." %(distro_codename),
-            [
-                "I don't know what to do",
-                "Continue. I already know of a patch to fix this problem.",
-                "Continue. Yes, I have discussed this with technical support.",
-                "Continue. I don't need technical support.",
-                "Please point me to where I can get technical support.",
-                ]
-            )
-        if response == None:
-            return False
-
-        # Fix is known
-        if 1 in response:
-            report['Tags'] += ' ' + 'patch'
-            ui.information("Thanks for helping improve Ubuntu!  Tip:  If you attach the fix to the bug report as a patch, it will be flagged to the developers and should get a swifter response.")
-            return True
-
-        # Referred by technical support
-        elif 2 in response:
-            report['Tags'] += ' ' + 'referred-by-support'
-            ui.information("Thanks for using technical support channels before filing this report.  In your bug report, please restate the issue and include a link or transcript of your discussion with them.")
-            return True
-
-        # Just want to file a bug report
-        elif 3 in response:
-            return True
-
-        # Anything else should be redirected to technical support channels
-        else:
-            ui.information("http://www.ubuntu.com/support/ is the best place to get free help with technical issues.")
-            report['UnreportableReason'] = 'Please work this issue through technical support channels first.'
-            return False
-
     return True
 
 def check_is_reportable(report, ui=None):
@@ -383,6 +352,22 @@ def attach_xorg_info(report, ui=None):
     attach_file_if_exists(report, '/var/log/Xorg.0.log', 'XorgLog')
     attach_file_if_exists(report, '/var/log/Xorg.0.log.old', 'XorgLogOld')
 
+    if os.path.lexists('/var/log/Xorg.0.log') and has_xorglog:
+        try:
+            xlog = XorgLog('/var/log/Xorg.0.log')
+            report['xserver.bootTime'] = xlog.boot_time
+            report['xserver.version'] = xlog.xserver_version
+            report['xserver.logfile'] = xlog.boot_logfile
+            report['xserver.devices'] = xlog.devices_table()
+            report['xserver.outputs'] = xlog.outputs_table()
+            report['xserver.configfile'] = str(xlog.xorg_conf_path)
+            report['xserver.errors'] = "\n".join(xlog.errors_filtered())
+            if xlog.video_driver is not None:
+                report['xserver.video_driver'] = xlog.video_driver.lower()
+        except:
+            # The parser can fail if the log file has invalid characters (e.g. funky EDID)
+            pass
+
     if ui:
         display_manager_files = {}
         if os.path.lexists('/var/log/lightdm'):
@@ -472,6 +457,8 @@ def attach_3d_info(report, ui=None):
         (report.get('SourcePackage','Unknown') == "compiz" and report.get('ProblemType', '') == 'Crash')
         ):
         report['CompositorRunning'] = 'compiz'
+
+        # Compiz Version
         compiz_version = command_output(['compiz', '--version'])
         if compiz_version:
             version = compiz_version.split(' ')[1]
@@ -479,6 +466,14 @@ def attach_3d_info(report, ui=None):
             if is_number(version):
                 compiz_version_string = 'compiz-%s' % version
                 report['Tags'] += ' ' + compiz_version_string
+
+        # Fullscreen Window Unredirection settings
+        report['CompositorUnredirectFSW'] = command_output(
+            ['gsettings','get','org.compiz.composite:/org/compiz/', 'unredirect-fullscreen-windows']
+            )
+        report['CompositorUnredirectDriverBlacklist'] = command_output(
+            ['gsettings','get','org.compiz.opengl:/org/compiz/', 'unredirect-driver-blacklist']
+            )
     elif is_process_running('kwin'):
         report['CompositorRunning'] = 'kwin'
     else:
@@ -594,7 +589,7 @@ def attach_gpu_hang_info(report, ui):
     report['GpuHangFrequency'] = choices[response[0]]
 
     # Don't ask more questions if bug is infrequent
-    if response < 3:
+    if response[0] < 3:
         return
 
     text = "When did you first start experiencing these lockups?"
